package com.bzd.web.controller.gxhpz;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.common.utils.DateUtils;
import com.bzd.common.utils.StringUtils;
import com.bzd.system.service.PharmaceuticalService;
import com.bzd.system.service.gxhpz.FollowPlanService;
import com.bzd.system.service.gxhpz.FollowTaskService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * 随访任务任务控制层
 * creator wsp
 */
@Controller
@RequestMapping("/task/followTask")
public class FollowTaskController extends BaseController {
    private String prefix = "task";
    @Autowired
    private FollowTaskService followTaskService;

    @Autowired
    private FollowPlanService followPlanService;
    @Autowired
    private PharmaceuticalService pharmaceuticalService;

    // 随访任务
    private String prefix_followUp = "dtp/followUp";
    /**
     *
     * 任务查询
     */
    @RequiresPermissions("gxhpz:task:list")
    @PostMapping("/followTaskList")
    @ResponseBody
    public TableDataInfo TaskList() throws Exception {
        PageData pd = this.getPageData();
        startPage();
        List<PageData> pageData = followTaskService.findForList(pd);
        return  getDataTable(pageData);
    }
    /**
     *
     * 计划查询
     */
    @RequiresPermissions("gxhpz:task:list")
    @PostMapping("/followPlanList")
    @ResponseBody
    public TableDataInfo PlanList() throws Exception {
        PageData pd = this.getPageData();
        startPage();
        List<PageData> pageData = followPlanService.findForList(pd);
        return  getDataTable(pageData);
    }

    /**
     * 任务新增保存
     */
    @Log(title = "任务新增", businessType = BusinessType.INSERT)
    @PostMapping("/saveFollowTask")
    @ResponseBody
    public AjaxResult saveFollowTask() throws Exception {
        PageData pd = this.getPageData();
        int result = followTaskService.save(pd);
        if(result>0){
            return AjaxResult.success("成功");
        }else {
            return AjaxResult.error("失败");
        }

    }
    /**
     * 计划新增保存
     */
    @Log(title = "计划新增", businessType = BusinessType.INSERT)
    @PostMapping("/saveFollowPlan")
    @ResponseBody
    public AjaxResult saveFollowPlan() throws Exception {
        PageData pd = this.getPageData();
        int result = followPlanService.save(pd);
        if(result>0){
            return AjaxResult.success("成功");
        }else {
            return AjaxResult.error("失败");
        }

    }
    @Log(title = "任务删除", businessType = BusinessType.DELETE)
    @PostMapping("/removeTask")
    @ResponseBody
    public AjaxResult removeTask() throws Exception
    {
        PageData pd = new PageData();
        pd = this.getPageData();
       Object id = pd.get("ids");
       if(StringUtils.isNotNull(id)){
           String[] split = id.toString().split(",");
           List<String> ids = Arrays.asList(split);
           Integer integer = followTaskService.del(ids);
           return toAjax(integer);

       }
        return AjaxResult.success("请选择要删除的数据");
    }
    @Log(title = "计划删除", businessType = BusinessType.DELETE)
    @PostMapping("/removePlan")
    @ResponseBody
    public AjaxResult removePlan() throws Exception
    {
        PageData pd = new PageData();
        pd = this.getPageData();
        Object id = pd.get("ids");
        if(StringUtils.isNotNull(id)){
            String[] split = id.toString().split(",");
            List<String> ids = Arrays.asList(split);
            Integer integer = followPlanService.del(ids);
            return toAjax(integer);

        }
        return AjaxResult.success("请选择要删除的数据");
    }

    /**
     * 保存任务修改信息/保存随访表单信息/保存随访计划信息
     */
    @RequiresPermissions("gxhpz:task:edit")
    @Log(title = "任务管理", businessType = BusinessType.UPDATE)
    @PostMapping("/followTaskEdit")
    @ResponseBody
    public AjaxResult followTaskEdit() throws Exception
    {
        PageData pd = this.getPageData();
        String id = (String) pd.get("id");
        String patientId = (String)pd.get("patientId");
        String returnMethod = (String)pd.get("returnMethod");
        String iscoordinate = (String)pd.get("iscoordinate");
        String returnObject = (String)pd.get("returnObject");
        if(StringUtils.isNotEmpty(returnMethod) && StringUtils.isNotEmpty(iscoordinate)
         && StringUtils.isNotEmpty(returnObject) && StringUtils.isNotEmpty(patientId) && StringUtils.isNotEmpty(id)){
            pd.put("taskStatus", "已完成");//任务状态：\r\n,0待执行，\r\n1已完成，\r\n2未完成，\r\n3已下发，\r\n4已取消
        }
        pd.put("operator", getSysUser().getLoginName());//登记人
        pd.put("updatedAt", DateUtils.getTime());//更新时间
        pd.put("actualFollowUpTime", DateUtils.getTime());//实际随访时间
        pd.put("completionTime", DateUtils.getTime());//完成时间
        Integer update = followTaskService.update(pd);
        if(update<=0){
            return error("保存失败");
        }
        return toAjax(update);
    }

    /**
     * 随访任务数据修改
     *
     * @return
     * @throws Exception
     */
    @RequiresPermissions("gxhpz:task:edit")
    @GetMapping("/FollowTaskEdit/{id}")
    public String FollowTaskEdit(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pd1 =new PageData();
        PageData pd2 =new PageData();
        PageData pd3=new PageData();
        PageData pd4=new PageData();
        PageData pd5=new PageData();
        PageData pdt1=new PageData();
        PageData pdt2=new PageData();
        PageData pageData = followTaskService.selectOneById(pd);//根据任务id查询随访任务数据

        if (StringUtils.isNotNull(pageData)) {
            pd2.put("patientId", pageData.get("patientId"));

            pd3.put("patientId", pageData.get("patientId"));//去查计划的条件 常规随访的
            pd3.put("mdmCode", pageData.get("mdmCode"));//去查计划的条件 常规随访的
            pd3.put("businessBelonging", "常规随访");//去查计划的条件 常规随访的

            pd4.put("patientId", pageData.get("patientId"));//去查计划的条件 脱落召回
            pd4.put("mdmCode", pageData.get("mdmCode"));//去查计划的条件 脱落召回
            pd4.put("businessBelonging", "脱落召回");//去查计划的条件 脱落召回

            pd5.put("id", pageData.get("patientId"));//去查购药记录的条件
            PageData Plan1 = followPlanService.selectPlanByCPB(pd3);//去查计划 常规随访的
            pd1 = pharmaceuticalService.selectPatientById(pd2);//查询患者信息
            if(StringUtils.isNotNull(Plan1)){

                pdt1.put("planId_cg", Plan1.get("id"));
                pd1.put("Plan1",Plan1);//常规随访的 类型的计划
                pd1.put("follow_up_person",Plan1.get("follow_up_person"));
                pd1.put("productName",Plan1.get("productName"));
                pd1.put("specification",Plan1.get("specification"));
                pd1.put("businessBelonging",Plan1.get("businessBelonging"));
                pd1.put("createdBy",Plan1.get("createdBy"));
                pd1.put("createdTime",  Plan1.get("createdTime1"));
                pd1.put("updatedBy",Plan1.get("updatedBy"));
                pd1.put("updatedTime",Plan1.get("updatedTime1"));
                // 获取原始的状态值并进行处理
                Integer status  = (Integer) Plan1.get("status");
                if (status != null) {
                    switch (status) {
                        case 0:
                            pd1.put("status","关闭");
                            break;
                        case 1:
                            pd1.put("status","进行中");
                            break;
                        case 2:
                            pd1.put("status","待开启");
                            break;
                        default:
                            pd1.put("status","待开启");
                            break;
                    }
                }
                List<PageData> listTask1= followTaskService.findForList(pdt1);//去查任务 常规随访
                if(listTask1.size()>0){
                    pd1.put("listTask1",listTask1);
                }
            }

            PageData Plan2 = followPlanService.selectPlanByCPB(pd4);//去查计划 脱落召回
            if(StringUtils.isNotNull(Plan2)){
                pdt2.put("planId_tl", Plan2.get("id"));
                List<PageData> listTask2= followTaskService.findForList(pdt2);//去查任务 脱落召回
                pd1.put("follow_up_person2",Plan2.get("follow_up_person"));
                pd1.put("productName2",Plan2.get("productName"));
                pd1.put("specification2",Plan2.get("specification"));
                pd1.put("businessBelonging2",Plan2.get("businessBelonging"));
                pd1.put("createdBy2",Plan2.get("createdBy"));
                pd1.put("createdTime2",Plan2.get("createdTime1"));
                pd1.put("updatedBy2",Plan2.get("updatedBy"));
                pd1.put("updatedTime2",Plan2.get("updatedTime1"));
                pd1.put("Plan2",Plan2);//脱落召回 类型的计划
                //pd1.put("status2",Plan2.get("status"));
                // 获取原始的状态值并进行处理
                Integer status2  = (Integer) Plan2.get("status");
                if (status2 != null) {
                    switch (status2) {
                        case 0:
                            pd1.put("status2","关闭");
                            break;
                        case 1:
                            pd1.put("status2","进行中");
                            break;
                        case 2:
                            pd1.put("status2","待开启");
                            break;
                        default:
                            pd1.put("status2","待开启");
                            break;
                    }
                }
                if(listTask2.size()>0){
                    pd1.put("listTask2",listTask2);
                }
            }
            PageData  Degree =followPlanService.getPerfectionDegree(pd2);//查询档案完善度百分比
            List<PageData>  records =pharmaceuticalService.getDrugPurchaseList(pd5);//去查购药记录
            pd1.put("taskId", pageData.get("id"));
            pd1.put("patientId", pd1.get("id"));
            if(StringUtils.isNotNull(Degree)){
                pd1.put("filledFieldsCount",Degree.get("filledFieldsCount"));//字段完成数量
                // 获取原始的完成度百分比并四舍五入
                Object completenessObj = Degree.get("completenessPercentage");
                if (completenessObj instanceof BigDecimal) {
                    BigDecimal completenessPercentage = (BigDecimal) completenessObj;
                    // 使用 BigDecimal 的setScale 方法进行四舍五入
                    BigDecimal roundedPercentage = completenessPercentage.setScale(0, BigDecimal.ROUND_HALF_UP);
                    pd1.put("completenessPercentage", roundedPercentage.intValue()); // 将四舍五入后的值放入 pd1
                }
            }
           if(records.size()>0){
               pd1.put("recordsData",records);
           }
            //本次任务单个
            pd1.put("bc_id",pageData.get("id"));//本次任务id
            pd1.put("bc_planId",pageData.get("planId"));//本次任务的计划id
            pd1.put("bc_appointmentDate",pageData.get("appointmentDate1"));//预约日期
            pd1.put("bc_businessBelonging",pageData.get("businessBelonging"));//businessBelonging
            pd1.put("bc_taskName",pageData.get("taskName"));//任务名称
            pd1.put("bc_taskTheme",pageData.get("taskTheme"));//任务主题
            pd1.put("bc_productName",pageData.get("productName"));//商品名
            pd1.put("bc_taskFollower",pageData.get("taskFollower"));//任务跟进人
            pd1.put("bc_taskStatus",pageData.get("taskStatus"));//任务状态 0待执行，\r\n1已完成，\r\n2未完成，\r\n3已下发，\r\n4已取消
            mmap.putAll(pd1);
        }else{
            mmap.put("未查询到数据 id",id);
        }
        return prefix_followUp + "/followUpEdit";
    }

    /**
     * 保存计划修改信息
     */
    @RequiresPermissions("gxhpz:task:edit")
    @Log(title = "计划管理", businessType = BusinessType.UPDATE)
    @PostMapping("/followPlanEdit")
    @ResponseBody
    public AjaxResult followPlanEdit() throws Exception
    {
        PageData pd = this.getPageData();
        Integer update = followPlanService.update(pd);
        if(update<=0){
            return error("修改失败");
        }
        return toAjax(update);
    }



    /**
     * 关闭计划
     */
    @RequiresPermissions("gxhpz:task:edit")
    @Log(title = "关闭计划", businessType = BusinessType.UPDATE)
    @PostMapping("/closePlan")
    @ResponseBody
    public AjaxResult closePlan() throws Exception
    {
        PageData pd = this.getPageData();
        Integer update = followPlanService.closePlan(pd);
        if(update<=0){
            return error("关闭计划失败");
        }
        return toAjax(update);
    }
    /**
     * 关闭任务
     */
    @RequiresPermissions("gxhpz:task:edit")
    @Log(title = "关闭任务", businessType = BusinessType.UPDATE)
    @PostMapping("/closeTask")
    @ResponseBody
    public AjaxResult closeTask() throws Exception
    {
        PageData pd = this.getPageData();
        Integer update = followTaskService.closeTask(pd);
        if(update<=0){
            return error("关闭任务划失败");
        }
        return toAjax(update);
    }



}
