package com.bzd.system.service.gxhpz;

import com.bzd.common.config.dao.DaoBase;
import com.bzd.common.config.dao.DaoSupport;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

import static com.bzd.common.utils.ShiroUtils.getSysUser;

@Service
public class FollowPlanService {
    @Autowired
    private DaoBase dao;
    @Resource(name = "daoSupport")
    private DaoSupport daoSupport;

    /**
     * 查询列表 
     * @param pd
     * @return 
     * @throws Exception
     */
    public List<PageData> findForList(final PageData pd) throws Exception {
        return (List<PageData>) daoSupport.findForList("followPlanMapper.selectFollowPlans", pd);
    }
    /**
     * 根据药品编码和患者id,业务归属 查询计划 只能出现一条数据
     * @param pd
     * @return
     * @throws Exception
     */
    public PageData selectPlanByCPB(final PageData pd) throws Exception {
        PageData pdo= (PageData) daoSupport.findForObject("followPlanMapper.selectPlanByCPB", pd);
        return pdo;
    }
    /**
     * 查询单个
     * @param pd
     * @return
     * @throws Exception
     */
    public Object selectOneById(final PageData pd) throws Exception {
        return daoSupport.findForObject("followPlanMapper.selectOneById", pd);
    }

    /**
     * 添加
     * @param pd
     * @return
     * @throws Exception
     */
    @Transactional(rollbackFor = Exception.class)
    public int save(final PageData pd) throws Exception {
      return  daoSupport.save("followPlanMapper.insertFollowPlan", pd);

    }

    /**
     *
     * @param ids
     * @return
     * @throws Exception
     */
    public Integer del(List<String> ids) throws Exception {
        return daoSupport.delete("followPlanMapper.deleteFollowPlansByIds", ids);
    }

    /**
     * 修改配置
     * @param pd
     * @return
     * @throws Exception
     */
    public Integer update(PageData pd) throws Exception {
        return daoSupport.update("followPlanMapper.updateFollowPlan", pd);
    }


    /**
     * 统计患者档案完善度
     * filledFieldsCount 字段完成数量 completenessPercentage完成百分比 id 患者id name 患者姓名
     * @param pd
     * @return
     * @throws Exception
     */
    public PageData getPerfectionDegree(PageData pd) throws Exception {
        PageData pjd= (PageData) daoSupport.findForObject("PharmaceuticalServiceMapper.statisticsPerfectionDegree", pd);
        return pjd;
    }

    /**
     * 关闭计划
     * @param pd
     * @return
     * @throws Exception
     */
    public Integer closePlan(PageData pd) throws Exception {
        pd.put("status", 0);
        pd.put("taskStatus", "已取消");//0待执行，\r\n1已完成，\r\n2未完成，\r\n3已下发，\r\n4已取消
        pd.put("updatedAt", DateUtils.getTime());//'更新时间'
        pd.put("operator", getSysUser().getLoginName());//'操作人'
        pd.put("updatedTime", DateUtils.getTime());//'更新时间'
        pd.put("updatedBy", getSysUser().getLoginName());//更新人

        int task = daoSupport.update("followTaskMapper.stopFollowTask", pd);
        int plan = daoSupport.update("followPlanMapper.closeFollowPlan", pd);
        if (task > 0 && plan > 0) {
            return 1;
        } else {
            return -1;
        }
    }


}
